<template>
  <el-dialog
    v-diadrag
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      label-width="80px"
      class="l-mes"
    >
      <el-row>
        <el-col :span="24">
          <el-form-item label="类型名称" prop="templateTypeName">
            <el-input
              v-model="dataForm.templateTypeName"
              placeholder="类型名称"
              clearable
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="24">
          <el-form-item label="所在页面" prop="dataType">
            <el-select
              v-model="dataForm.dataType"
              placeholder="所在页面"
              style="width: 100%"
            >
              <el-option
                v-for="item in dataTypeList"
                :key="item.id"
                :label="item.label"
                :value="item.value"
              />
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`dataFormSubmit`"
        >确定</el-button
      >
    </span>
  </el-dialog>
</template>

<script>
import { getObj, addObj, putObj } from '@/api/basic/customizeparamtemplatetype'
import { remote } from '@/api/admin/dict'
export default {
  data() {
    return {
      visible: false,
      dataTypeList: [],
      dataForm: {
        id: 0,
        templateTypeName: '',
        dataType: ''
      },
      dataRule: {
        templateTypeName: [
          { required: true, message: '类型名称字段不能为空', trigger: 'blur' }
        ],
        dataType: [
          { required: true, message: '所在页面字段不能为空', trigger: 'blur' }
        ]
      },
      isSubmit: false
    }
  },
  created() {
    this.getParamApplyDict()
  },
  methods: {
    getParamApplyDict() {
      remote('routing_operation_template_data_type').then((response) => {
        if (response.data.code === 0) {
          this.dataTypeList = response.data.data
        } else {
          this.dataTypeList = []
        }
      })
    },
    init(id) {
      this.dataForm.id = id || 0
      this.visible = true
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        if (this.dataForm.id) {
          getObj(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
          })
        }
      })
    },
    // 表单提交
    dataFormSubmit() {
      this.isSubmit = true
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          if (this.dataForm.id) {
            putObj(this.dataForm).then((data) => {
              this.$message.success('修改成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          } else {
            addObj(this.dataForm).then((data) => {
              this.$message.success('添加成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          }
        } else {
          this.isSubmit = false
        }
      })
    }
  }
}
</script>
